@@ -28,7 +28,8 @@ return {
   exports = {
     date = date
   },
-documentation = [[\begin{document}
+documentation = [[
+\begin{document}
 The \autodoc:package{date} package provides the \autodoc:command{\date} command, which simply
 outputs the date using the system’s date function. You can customize
 the format by passing the \autodoc:parameter{format} parameter, following the
