@@ -1,7 +1,7 @@
-local nodefactory = require("core/nodefactory")
+local nodefactory = require("core.nodefactory")
 local hb = require("justenoughharfbuzz")
-local ot = require("core/opentype-parser")
-local syms = require("packages/math/unicode-symbols")
+local ot = require("core.opentype-parser")
+local syms = require("packages.math.unicode-symbols")
 
 local atomType = syms.atomType
 local symbolDefaults = syms.symbolDefaults
@@ -93,13 +93,6 @@ local mathScriptConversionTable = {
   }
 }
 
-SILE.settings.declare({parameter = "math.font.family", type = "string", default = "Libertinus Math"})
-SILE.settings.declare({parameter = "math.font.filename", type = "string", default = ""})
-SILE.settings.declare({parameter = "math.font.size", type = "integer", default = 10})
--- Whether to show debug boxes around mboxes
-SILE.settings.declare({parameter = "math.debug.boxes", type = "boolean", default = false})
-SILE.settings.declare({parameter = "math.displayskip", type = "VGlue", default = SILE.nodefactory.vglue("2ex plus 1pt")})
-
 local function retrieveMathTable(options)
   print("options.family = " .. options.family)
   local face = SILE.font.cache(options, SILE.shaper.getFace)
@@ -136,10 +129,10 @@ local mathCache
 local function getMathMetrics()
   if mathCache then return mathCache end
   local options = {
-    family=SILE.settings.get("math.font.family"),
-    size=SILE.settings.get("math.font.size")
+    family=SILE.settings:get("math.font.family"),
+    size=SILE.settings:get("math.font.size")
   }
-  local filename = SILE.settings.get("math.font.filename")
+  local filename = SILE.settings:get("math.font.filename")
   if filename and filename ~= "" then options.filename = filename end
   mathCache = retrieveMathTable(options)
   return mathCache
@@ -257,10 +250,10 @@ elements.mbox = pl.class({
     self.mode = mathMode.display
     self.atom = atomType.ordinary
     local options = {
-      family=SILE.settings.get("math.font.family"),
-      size=SILE.settings.get("math.font.size")
+      family=SILE.settings:get("math.font.family"),
+      size=SILE.settings:get("math.font.size")
     }
-    local filename = SILE.settings.get("math.font.filename")
+    local filename = SILE.settings:get("math.font.filename")
     if filename and filename ~= "" then options.filename = filename end
     self.options = SILE.font.loadDefaults(options)
   end,
@@ -312,7 +305,7 @@ elements.mbox = pl.class({
   -- Output the node and all its descendants
   outputTree = function(self, x, y, line)
     self:output(x, y, line)
-    local debug = SILE.settings.get("math.debug.boxes")
+    local debug = SILE.settings:get("math.debug.boxes")
     if debug and not (self:is_a(elements.space)) then
       SILE.outputter:setCursor(scaleWidth(x, line), y.length)
       SILE.outputter:debugHbox(
@@ -801,7 +794,7 @@ elements.text = pl.class({
       end
     end
     for attribute,value in pairs(attributes) do
-      SU.debug("math", "attribute = "..attribute..", value = "..value)
+      SU.debug("math", "attribute = " .. attribute .. ", value = " .. tostring(value))
       self[attribute] = value
     end
   end,
@@ -814,7 +807,7 @@ elements.text = pl.class({
     -- Use bigger variants for big operators in display style
     if isDisplayMode(self.mode) and self.largeop then
       -- We copy the glyph list to avoid modifying the shaper's cache. Yes.
-      glyphs = std.tree.clone(glyphs)
+      glyphs = pl.tablex.deepcopy(glyphs)
       local constructions = mathMetrics.mathVariants
         .vertGlyphConstructions[glyphs[1].gid]
       if constructions then
@@ -895,12 +888,12 @@ elements.text = pl.class({
     -- required.  TODO: implement assembly of stretchable glyphs form
     -- their parts for cases when the biggest variant is not big enough.
     -- We copy the glyph list to avoid modifying the shaper's cache. Yes.
-    local glyphs = std.tree.clone(self.value.items)
+    local glyphs = pl.tablex.deepcopy(self.value.items)
     local constructions = getMathMetrics().mathVariants
       .vertGlyphConstructions[glyphs[1].gid]
     if constructions then
       local variants = constructions.mathGlyphVariantRecord
-      SU.debug("math", "stretch: variants = " .. variants)
+      SU.debug("math", "stretch: variants = " .. tostring(variants))
       local closest
       local closestI
       local m = requiredAdvance - (self.depth+self.height):tonumber() * upem/sz
@@ -914,7 +907,7 @@ elements.text = pl.class({
           m = diff
         end
       end
-      SU.debug("math", "stretch: closestI = " .. closestI)
+      SU.debug("math", "stretch: closestI = " .. tostring(closestI))
       if closest then
         -- Now we have to re-shape the glyph chain. We will assume there
         -- is only one glyph.
